pub enum BucketCredential {
    Hmac {
        access_key: String,
        secret_key: String,
    },
    ApiKey(String),
}

impl BucketCredential {
    pub fn parse(raw: &str) -> Self {
        if let Ok(json_val) = serde_json::from_str::<serde_json::Value>(raw) {
            if let (Some(ak), Some(sk)) = (json_val.get("access_key"), json_val.get("secret_key")) {
                return BucketCredential::Hmac {
                    access_key: ak.as_str().unwrap().to_owned(),
                    secret_key: sk.as_str().unwrap().to_owned(),
                };
            }
            if let Some(apikey) = json_val.get("api_key").or_else(|| json_val.get("apikey")) {
                return BucketCredential::ApiKey(apikey.as_str().unwrap().to_owned());
            }
        }

        BucketCredential::ApiKey(raw.to_owned())
    }
}
